==> haskell-monad-memo-0.5.4-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-memo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-memo
version:              0.5.4
visibility:           public
id:                   monad-memo-0.5.4-HoVtm1dOl6gCHZia44mAJv
key:                  monad-memo-0.5.4-HoVtm1dOl6gCHZia44mAJv
license:              BSD-3-Clause
maintainer:           eduard.sergeev@gmail.com
author:               Eduard Sergeev
homepage:             https://github.com/EduardSergeev/monad-memo
synopsis:             Memoization monad transformer
description:
    Memoization monad transformer supporting most of the standard monad transformers and a range of memoization cache types: from default pure maps to extremely fast mutable vectors

    To add memoization behaviour to a monadic function:

    1) Add '\''Control.Monad.Memo.memo'\'' combinator at the point when memoization is required (i.e. recursive call)

    >import Control.Monad.Memo
    >
    >fibm 0 = return 0
    >fibm 1 = return 1
    >fibm n = do
    >  n1 <- memo fibm (n-1)
    >  n2 <- memo fibm (n-2)
    >  return (n1+n2)

    2) Use appropriate /*eval*/ or /*run*/ function to evaluate resulting `MonadMemo` monad:

    >startEvalMemo (fibm 100)

    See detailed description and examples: "Control.Monad.Memo"

category:             Control, Monad
abi:                  693ca6b4f23fc3de8f842abc335ea3f9
exposed:              True
exposed-modules:
    Control.Monad.Memo Control.Monad.Memo.Array
    Control.Monad.Memo.Array.Instances Control.Monad.Memo.Class
    Control.Monad.Memo.Vector Control.Monad.Memo.Vector.Expandable
    Control.Monad.Memo.Vector.Instances
    Control.Monad.Memo.Vector.Unsafe Control.Monad.Trans.Memo.Map
    Control.Monad.Trans.Memo.ReaderCache Control.Monad.Trans.Memo.State
    Control.Monad.Trans.Memo.StateCache Data.MapLike
    Data.MapLike.Instances Data.MaybeLike Data.MaybeLike.Instances

import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-memo-0.5.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-memo-0.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-memo
hs-libraries:         HSmonad-memo-0.5.4-HoVtm1dOl6gCHZia44mAJv
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
    primitive-0.7.4.0-LS5OACsFMkWJjOUaCwrwBF transformers-0.5.6.2
    vector-0.13.1.0-6G7HaD4XqvmDrN5OhcYDtS

haddock-interfaces:   /usr/share/doc/haskell-monad-memo/html/monad-memo.haddock
haddock-html:         /usr/share/doc/haskell-monad-memo/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-memo-0.5.4-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-memo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-memo
version:              0.5.4
visibility:           public
id:                   monad-memo-0.5.4-FijVqcL95GMDmWYqOAfD0K
key:                  monad-memo-0.5.4-FijVqcL95GMDmWYqOAfD0K
license:              BSD-3-Clause
maintainer:           eduard.sergeev@gmail.com
author:               Eduard Sergeev
homepage:             https://github.com/EduardSergeev/monad-memo
synopsis:             Memoization monad transformer
description:
    Memoization monad transformer supporting most of the standard monad transformers and a range of memoization cache types: from default pure maps to extremely fast mutable vectors

    To add memoization behaviour to a monadic function:

    1) Add '\''Control.Monad.Memo.memo'\'' combinator at the point when memoization is required (i.e. recursive call)

    >import Control.Monad.Memo
    >
    >fibm 0 = return 0
    >fibm 1 = return 1
    >fibm n = do
    >  n1 <- memo fibm (n-1)
    >  n2 <- memo fibm (n-2)
    >  return (n1+n2)

    2) Use appropriate /*eval*/ or /*run*/ function to evaluate resulting `MonadMemo` monad:

    >startEvalMemo (fibm 100)

    See detailed description and examples: "Control.Monad.Memo"

category:             Control, Monad
abi:                  f11d0c439c4c9ac7075c50d0969bbe4c
exposed:              True
exposed-modules:
    Control.Monad.Memo Control.Monad.Memo.Array
    Control.Monad.Memo.Array.Instances Control.Monad.Memo.Class
    Control.Monad.Memo.Vector Control.Monad.Memo.Vector.Expandable
    Control.Monad.Memo.Vector.Instances
    Control.Monad.Memo.Vector.Unsafe Control.Monad.Trans.Memo.Map
    Control.Monad.Trans.Memo.ReaderCache Control.Monad.Trans.Memo.State
    Control.Monad.Trans.Memo.StateCache Data.MapLike
    Data.MapLike.Instances Data.MaybeLike Data.MaybeLike.Instances

import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-memo-0.5.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-memo-0.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-memo
hs-libraries:         HSmonad-memo-0.5.4-FijVqcL95GMDmWYqOAfD0K
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
    primitive-0.7.4.0-6AwD3HztCbd2gLkP35eH21 transformers-0.5.6.2
    vector-0.13.1.0-JX40x5KeA95953did9SvPW

haddock-interfaces:   /usr/share/doc/haskell-monad-memo/html/monad-memo.haddock
haddock-html:         /usr/share/doc/haskell-monad-memo/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
